import markdown
from pykwiki.core import conf
import yaml
import jinja2
import re

UML_RE = r'^(\{uml\})(.+?)(\{enduml\})'
PLANT_UML_CONFIGS = {}

class UMLPreprocessor(markdown.preprocessors.Preprocessor):

    def __init__(self, md):
        self.config = md.plant_options

    def run(self, lines):

        try:
            import plantuml
        except:
            print("WARNING: Plantuml not installed for this python version: ext.uml disabled.")
            return lines
    
        
        text = '\n'.join(lines)
        pat = re.compile(UML_RE, re.DOTALL|re.M)
        ms = pat.findall(text)
        if not ms:
            return lines

        puml = plantuml.PlantUML(**self.config)

        for m in ms:
            uml = m[1]
            url = puml.get_url(uml)
            text = pat.sub('<img src="%s"/>'%(url), text, 1)  
 
        return text.split('\n')

class UMLExtension(markdown.Extension):

    def __init__(self, **kwargs):
        self.config = kwargs

    def extendMarkdown(self, md, md_globals):
        md.plant_options = self.config
        md.preprocessors.add('pykwiki.uml', UMLPreprocessor(md), '_begin')

def makeExtension(**configs):
    PLANT_UML_CONFIGS = configs
    return UMLExtension(**configs)

if __name__ == "__main__":
    import doctest
    doctest.testmod()



#!/usr/bin/env python
from setuptools import setup, find_packages
import os
import sys

os.chdir(os.path.dirname(os.path.abspath(__file__)))
sys.path.insert(0, os.path.dirname(__file__))
from pykwiki import __version__

setup(name='pykwiki',
    version = __version__,
    description = 'A simple pure-python wiki engine.',
    long_description = '''
A pure-python, light-weight, static wiki, blog, and website engine designed to be
fast to setup, secure, and to handle lots of web traffic.
    ''',
    author = 'Aaron Meier',
    author_email = 'webgovernor@gmail.com',
    packages = ['pykwiki','pykwiki.ext'],
    package_dir={'pykwiki':'pykwiki'},
    scripts=['pykwiki/scripts/pykwiki', 'pykwiki/scripts/pk'],
    package_data={
        'pykwiki':[
            'data/*.zip',
            'data/default_data/*.yaml',
            'data/default_data/source/*.md',
            'data/default_data/source/tpl/*.tpl',
            'data/default_data/styles/*/*.yaml',
            'data/default_data/styles/*/*.scss',
            'data/default_data/styles/*/static/*.*',
            'data/default_theme/*.html',
            'data/default_theme/*.xml',
            'data/default_theme/static/*.js',
            'data/default_theme/static/mustachejs/*.js',
            'data/default_theme/static/codehilite/*.css',
            'data/default_theme/static/fonts/*.css',
            'data/default_theme/static/fonts/*.ttf',
            'data/default_theme/static/fonts/*.eot',
            'data/default_theme/static/fonts/*.woff',
        ]},
    url = 'http://pykwiki.nullism.com',
    license = 'MIT',
    install_requires = ['markdown>=2.6', 'jinja2>=2.6', 'pyyaml>=3.0', 'pyscss>=1.3.4'],
    provides = ['pykwiki']
)

